@@ -118,19 +118,11 @@ bool Base_DB::fill_from_database()
 }
 
 //static:
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
 sharedptr<SharedConnection> Base_DB::connect_to_server(Gtk::Window* parent_window)
-#else
-sharedptr<SharedConnection> Base_DB::connect_to_server(Gtk::Window* parent_window, std::auto_ptr<ExceptionConnection>& error)
-#endif
 {
   BusyCursor busy_cursor(parent_window);
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   return ConnectionPool::get_and_connect();
-#else
-  return ConnectionPool::get_and_connect(error);
-#endif
 }
 
 void Base_DB::handle_error(const Glib::Exception& ex)
@@ -154,6 +146,7 @@ void Base_DB::handle_error(const std::exception& ex)
   dialog.set_secondary_text(ex.what());
   //TODO: dialog.set_transient_for(*get_application());
 #endif
+
   dialog.run();
 }
 
@@ -347,20 +340,12 @@ sharedptr<Field> Base_DB::change_column(const Glib::ustring& table_name, const s
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
   sharedptr<Field> result = check_field_change_constraints(field_old, field);
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     connection_pool->change_column(table_name, field_old, result);
   }
   catch(const Glib::Error& ex)
   {
-#else
-  std::auto_ptr<Glib::Error> error;
-  connection_pool->change_column(table_name, field_old, result, error);
-  if(error.get())
-  {
-    const Glib::Error& ex = *error;
-#endif
     handle_error(ex);
 //    Gtk::MessageDialog window(*parent_window, Utils::bold_message(ex.what()), true, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_OK);
 //    window.run();
@@ -383,20 +368,12 @@ bool Base_DB::change_columns(const Glib::ustring& table_name, const type_vec_con
 
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     connection_pool->change_columns(table_name, old_fields, pass_fields);
   }
   catch(const Glib::Error& ex)
   {
-#else
-  std::auto_ptr<Glib::Error> error;
-  connection_pool->change_columns(table_name, old_fields, pass_fields, error);
-  if(error.get())
-  {
-    const Glib::Error& ex = *error;
-#endif
     handle_error(ex);
 //    Gtk::MessageDialog window(*parent_window, Utils::bold_message(ex.what()), true, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_OK);
 //    window.run();
@@ -410,7 +387,6 @@ bool Base_DB::change_columns(const Glib::ustring& table_name, const type_vec_con
 
 Glib::RefPtr<Gnome::Gda::Connection> Base_DB::get_connection()
 {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   sharedptr<SharedConnection> sharedconnection;
   try
   {
@@ -418,21 +394,12 @@ Glib::RefPtr<Gnome::Gda::Connection> Base_DB::get_connection()
   }
   catch (const Glib::Error& error)
   {
-    std::cerr << "Base_DB::get_connection(): " << error.what() << std::endl;
+    std::cerr << G_STRFUNC << ": " << error.what() << std::endl;
   }
-#else
-  std::auto_ptr<ExceptionConnection> error;
-  sharedptr<SharedConnection> sharedconnection = connect_to_server(0, error);
-  if(error.get())
-  {
-    std::cerr << "Base_DB::get_connection(): " << error->what() << std::endl;
-    // TODO: Rethrow?
-  }
-#endif
 
   if(!sharedconnection)
   {
-    std::cerr << "Base_DB::get_connection(): No connection yet." << std::endl;
+    std::cerr << G_STRFUNC << ": No connection yet." << std::endl;
     return Glib::RefPtr<Gnome::Gda::Connection>(0);
   }
 
@@ -454,6 +421,8 @@ sharedptr<LayoutItem_Field> Base_DB::offer_field_list_select_one_field(const sha
 
   Dialog_ChooseField* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return result;
 
   if(dialog)
   {
@@ -482,6 +451,8 @@ Base_DB::type_list_field_items Base_DB::offer_field_list(const Glib::ustring& ta
 
   Dialog_ChooseField* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return result;
 
   if(dialog)
   {
@@ -502,7 +473,7 @@ Base_DB::type_list_field_items Base_DB::offer_field_list(const Glib::ustring& ta
   return result;
 }
 
-bool Base_DB::offer_item_formatting(const sharedptr<LayoutItem_WithFormatting>& layout_item, Gtk::Window* transient_for)
+bool Base_DB::offer_non_field_item_formatting(const sharedptr<LayoutItem_WithFormatting>& layout_item, Gtk::Window* transient_for)
 {
   bool result = false;
 
@@ -512,7 +483,7 @@ bool Base_DB::offer_item_formatting(const sharedptr<LayoutItem_WithFormatting>&
 
   add_view(&dialog);
 
-  dialog.set_item(layout_item);
+  dialog.set_item(layout_item, false);
 
   const int response = dialog.run();
   if(response == Gtk::RESPONSE_OK)
@@ -528,20 +499,21 @@ bool Base_DB::offer_item_formatting(const sharedptr<LayoutItem_WithFormatting>&
   return result;
 }
 
-sharedptr<LayoutItem_Field> Base_DB::offer_field_formatting(const sharedptr<const LayoutItem_Field>& start_field, const Glib::ustring& table_name, Gtk::Window* transient_for)
+sharedptr<LayoutItem_Field> Base_DB::offer_field_formatting(const sharedptr<const LayoutItem_Field>& start_field, const Glib::ustring& table_name, Gtk::Window* transient_for, bool show_editable_options)
 {
   sharedptr<LayoutItem_Field> result;
 
   Dialog_FieldLayout* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return result;
 
   if(transient_for)
     dialog->set_transient_for(*transient_for);
 
   add_view(dialog);
 
-  dialog->set_field(start_field, table_name);
-
+  dialog->set_field(start_field, table_name, show_editable_options);
 
   const int response = dialog->run();
   if(response == Gtk::RESPONSE_OK)
@@ -564,6 +536,8 @@ sharedptr<LayoutItem_Text> Base_DB::offer_textobject(const sharedptr<LayoutItem_
 
   Dialog_TextObject* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return result;
 
   if(transient_for)
     dialog->set_transient_for(*transient_for);
@@ -588,6 +562,8 @@ sharedptr<LayoutItem_Image> Base_DB::offer_imageobject(const sharedptr<LayoutIte
 
   Dialog_ImageObject* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return result;
 
   if(transient_for)
     dialog->set_transient_for(*transient_for);
@@ -612,6 +588,8 @@ sharedptr<LayoutItem_Notebook> Base_DB::offer_notebook(const sharedptr<LayoutIte
 
   Dialog_Notebook* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return result;
 
   if(transient_for)
     dialog->set_transient_for(*transient_for);
@@ -632,24 +610,6 @@ sharedptr<LayoutItem_Notebook> Base_DB::offer_notebook(const sharedptr<LayoutIte
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-void Base_DB::fill_full_field_details(const Glib::ustring& parent_table_name, sharedptr<LayoutItem_Field>& layout_item)
-{
-  if(!layout_item)
-  {
-    std::cerr << "Base_DB::fill_full_field_details(): layout_item was null." << std::endl;
-  }
-
-  const Glib::ustring table_name = layout_item->get_table_used(parent_table_name);
-
-  Document* document = get_document();
-  if(!document)
-  {
-    std::cerr << "Base_DB::fill_full_field_details(): document was null." << std::endl;
-  }
-
-  layout_item->set_full_field_details( get_document()->get_field(table_name, layout_item->get_name()) );
-}
-
 sharedptr<Field> Base_DB::get_fields_for_table_one_field(const Glib::ustring& table_name, const Glib::ustring& field_name) const
 {
   //Initialize output parameter:
@@ -725,7 +685,7 @@ sharedptr<Field> Base_DB::get_field_primary_key_for_table(const Glib::ustring& t
   {
     //TODO_Performance: Cache this result?
     Document::type_vec_fields fields = document->get_table_fields(table_name);
-    //std::cout << "Base_DB::get_field_primary_key_for_table(): table=" << table_name << ", fields count=" << fields.size() << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": table=" << table_name << ", fields count=" << fields.size() << std::endl;
     for(Document::type_vec_fields::iterator iter = fields.begin(); iter != fields.end(); ++iter)
     {
       sharedptr<Field> field = *iter;
@@ -742,7 +702,7 @@ sharedptr<Field> Base_DB::get_field_primary_key_for_table(const Glib::ustring& t
   return sharedptr<Field>();
 }
 
-void Base_DB::get_table_fields_to_show_for_sequence_add_group(const Glib::ustring& table_name, const Privileges& table_privs, const type_vec_fields& all_db_fields, const sharedptr<LayoutGroup>& group, Base_DB::type_vecLayoutFields& vecFields) const
+void Base_DB::get_table_fields_to_show_for_sequence_add_group(const Glib::ustring& table_name, const Privileges& table_privs, const type_vec_fields& all_db_fields, const sharedptr<LayoutGroup>& group, Base_DB::type_vecConstLayoutFields& vecFields) const
 {
   //g_warning("Box_Data::get_table_fields_to_show_for_sequence_add_group(): table_name=%s, all_db_fields.size()=%d, group->name=%s", table_name.c_str(), all_db_fields.size(), group->get_name().c_str());
 
@@ -776,7 +736,7 @@ void Base_DB::get_table_fields_to_show_for_sequence_add_group(const Glib::ustrin
         }
         else
         {
-          std::cerr << "Base_DB::get_table_fields_to_show_for_sequence_add_group(): related field not found: field=" << item->get_layout_display_name() << std::endl;
+          std::cerr << G_STRFUNC << ": related field not found: field=" << item->get_layout_display_name() << std::endl;
         }
       }
       else //It's a regular field in the table:
@@ -789,7 +749,7 @@ void Base_DB::get_table_fields_to_show_for_sequence_add_group(const Glib::ustrin
           sharedptr<LayoutItem_Field> layout_item = item_field;
           layout_item->set_full_field_details(*iterFind); //Fill the LayoutItem with the full field information.
 
-          //std::cout << "get_table_fields_to_show_for_sequence_add_group(): name=" << layout_item->get_name() << std::endl;
+          //std::cout << "debug: " << G_STRFUNC << ": name=" << layout_item->get_name() << std::endl;
 
           //Prevent editing of the field if the user may not edit this table:
           layout_item->m_priv_view = table_privs.m_view;
@@ -820,7 +780,7 @@ void Base_DB::get_table_fields_to_show_for_sequence_add_group(const Glib::ustrin
   }
 }
 
-Base_DB::type_vecLayoutFields Base_DB::get_table_fields_to_show_for_sequence(const Glib::ustring& table_name, const Document::type_list_layout_groups& mapGroupSequence) const
+Base_DB::type_vecConstLayoutFields Base_DB::get_table_fields_to_show_for_sequence(const Glib::ustring& table_name, const Document::type_list_layout_groups& mapGroupSequence) const
 {
   //Get field definitions from the database, with corrections from the document:
   type_vec_fields all_fields = get_fields_for_table(table_name);
@@ -828,7 +788,7 @@ Base_DB::type_vecLayoutFields Base_DB::get_table_fields_to_show_for_sequence(con
   const Privileges table_privs = Privs::get_current_privs(table_name);
 
   //Get fields that the document says we should show:
-  type_vecLayoutFields result;
+  type_vecConstLayoutFields result;
   const Document* pDoc = dynamic_cast<const Document*>(get_document());
   if(pDoc)
   {
@@ -936,12 +896,7 @@ void Base_DB::calculate_field_in_all_records(const Glib::ustring& table_name, co
   const int rows_count = data_model->get_n_rows();
   for(int row = 0; row < rows_count; ++row)
   {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     const Gnome::Gda::Value primary_key_value = data_model->get_value_at(0, row);
-#else
-    std::auto_ptr<Glib::Error> error;
-    const Gnome::Gda::Value primary_key_value = data_model->get_value_at(0, row, error);
-#endif
 
     if(!Conversions::value_is_empty(primary_key_value))
     {
@@ -1046,13 +1001,7 @@ void Base_DB::calculate_field(const LayoutFieldInRecord& field_in_record)
         if(field)
         {
           //We need the connection when we run the script, so that the script may use it.
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
           sharedptr<SharedConnection> sharedconnection = connect_to_server(0 /* parent window */);
-#else
-          std::auto_ptr<ExceptionConnection> error;
-          sharedptr<SharedConnection> sharedconnection = connect_to_server(0 /* parent window */, error);
-          // TODO: Rethrow?
-#endif
 
           g_assert(sharedconnection);
 
@@ -1120,27 +1069,16 @@ Base_DB::type_map_fields Base_DB::get_record_field_values_for_calculation(const
       Glib::RefPtr<Gnome::Gda::SqlBuilder> query = Utils::build_sql_select_with_key(table_name, fieldsToGet, primary_key, primary_key_value);
 
       Glib::RefPtr<const Gnome::Gda::DataModel> data_model;
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
       try
       {
         data_model = DbUtils::query_execute_select(query);
       }
       catch(const Glib::Exception& ex)
       {
-        std::cerr << "Base_DB::get_record_field_values_for_calculation(): Exception while executing SQL: " << query << std::endl;
+        std::cerr << G_STRFUNC << ": Exception while executing SQL: " << query << std::endl;
         handle_error(ex);
         return field_values;
       }
-#else
-      //TODO: Seems there is no error handling in DbUtils::query_execute_select() without exceptions
-      std::auto_ptr<Glib::Error> error;
-      data_model = DbUtils::query_execute_select(query);
-      if (error.get())
-      {
-        std::cerr << "Base_DB::get_record_field_values_for_calculation(): Exception while executing SQL: " << query << std::endl;
-        return field_values;
-      }
-#endif
       if(data_model && data_model->get_n_rows())
       {
         int col_index = 0;
@@ -1148,11 +1086,7 @@ Base_DB::type_map_fields Base_DB::get_record_field_values_for_calculation(const
         {
           //There should be only 1 row. Well, there could be more but we will ignore them.
           sharedptr<const Field> field = *iter;
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
           Gnome::Gda::Value value = data_model->get_value_at(col_index, 0);
-#else
-          Gnome::Gda::Value value = data_model->get_value_at(col_index, 0, error);
-#endif
           //Never give a NULL-type value to the python calculation for types that don't use them:
           //to prevent errors:
           if(value.is_null())
@@ -1210,13 +1144,13 @@ bool Base_DB::set_field_value_in_database(const LayoutFieldInRecord& layoutfield
   //row is invalid, and ignored, for Box_Data_Details.
   if(!(field_in_record.m_field))
   {
-    std::cerr << "Base_DB::set_field_value_in_database(): field_in_record.m_field is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": field_in_record.m_field is empty." << std::endl;
     return false;
   }
 
   if(!(field_in_record.m_key))
   {
-    std::cerr << "Base_DB::set_field_value_in_database(): field_in_record.m_key is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": field_in_record.m_key is empty." << std::endl;
     return false;
   }
 
@@ -1231,18 +1165,15 @@ bool Base_DB::set_field_value_in_database(const LayoutFieldInRecord& layoutfield
         builder->add_field_id(field_in_record.m_key->get_name(), field_in_record.m_table_name),
         builder->add_expr_as_value(field_in_record.m_key_value)));
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     try //TODO: The exceptions are probably already handled by query_execute(
-#endif
     {
       const bool test = DbUtils::query_execute(builder); //TODO: Respond to failure.
       if(!test)
       {
-        std::cerr << "Box_Data::set_field_value_in_database(): UPDATE failed." << std::endl;
+        std::cerr << G_STRFUNC << ": UPDATE failed." << std::endl;
         return false; //failed.
       }
     }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     catch(const Glib::Exception& ex)
     {
       handle_error(ex);
@@ -1253,7 +1184,6 @@ bool Base_DB::set_field_value_in_database(const LayoutFieldInRecord& layoutfield
       handle_error(ex);
       return false;
     }
-#endif
 
     //Get-and-set values for lookup fields, if this field triggers those relationships:
     do_lookups(layoutfield_in_record, row, field_value);
@@ -1282,13 +1212,13 @@ Gnome::Gda::Value Base_DB::get_field_value_in_database(const LayoutFieldInRecord
   //row is invalid, and ignored, for Box_Data_Details.
   if(!(field_in_record.m_field))
   {
-    std::cerr << "Base_DB:gset_field_value_in_database(): field_in_record.m_field is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": field_in_record.m_field is empty." << std::endl;
     return result;
   }
 
   if(!(field_in_record.m_key))
   {
-    std::cerr << "Base_DB::get_field_value_in_database(): field_in_record.m_key is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": field_in_record.m_key is empty." << std::endl;
     return result;
   }
 
@@ -1303,12 +1233,7 @@ Gnome::Gda::Value Base_DB::get_field_value_in_database(const LayoutFieldInRecord
   {
     if(data_model->get_n_rows())
     {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
       result = data_model->get_value_at(0, 0);
-#else
-      std::auto_ptr<Glib::Error> value_error;
-      result = data_model->get_value_at(0, 0, value_error);
-#endif
     }
   }
   else
@@ -1326,13 +1251,13 @@ Gnome::Gda::Value Base_DB::get_field_value_in_database(const sharedptr<Field>& f
   //row is invalid, and ignored, for Box_Data_Details.
   if(!field)
   {
-    std::cerr << "Base_DB:gset_field_value_in_database(): field is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": field is empty." << std::endl;
     return result;
   }
 
   if(found_set.m_where_clause.empty())
   {
-    std::cerr << "Base_DB::get_field_value_in_database(): where_clause is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": where_clause is empty." << std::endl;
     return result;
   }
 
@@ -1351,12 +1276,7 @@ Gnome::Gda::Value Base_DB::get_field_value_in_database(const sharedptr<Field>& f
   {
     if(data_model->get_n_rows())
     {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
       result = data_model->get_value_at(0, 0);
-#else
-      std::auto_ptr<Glib::Error> value_error;
-      result = data_model->get_value_at(0, 0, value_error);
-#endif
     }
   }
   else
@@ -1370,7 +1290,7 @@ Gnome::Gda::Value Base_DB::get_field_value_in_database(const sharedptr<Field>& f
 
 void Base_DB::do_calculations(const LayoutFieldInRecord& field_changed, bool first_calc_field)
 {
-  //std::cout << "debug: Base_DB::do_calcualtions(): field_changed=" << field_changed.m_field->get_name() << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": field_changed=" << field_changed.m_field->get_name() << std::endl;
 
   if(first_calc_field)
   {
@@ -1524,12 +1444,12 @@ void Base_DB::do_lookups(const LayoutFieldInRecord& field_in_record, const Gtk::
    //TODO_performance: There is a LOT of iterating and copying here.
    const Glib::ustring strFieldName = field_in_record.m_field->get_name();
    const type_list_lookups lookups = get_lookup_fields(field_in_record.m_table_name, strFieldName);
-   //std::cout << "Base_DB::do_lookups(): lookups size=" << lookups.size() << std::endl;
+   //std::cout << "debug: " << G_STRFUNC << ": lookups size=" << lookups.size() << std::endl;
    for(type_list_lookups::const_iterator iter = lookups.begin(); iter != lookups.end(); ++iter)
    {
      sharedptr<const LayoutItem_Field> layout_item = iter->first;
 
-     //std::cout << "Base_DB::do_lookups(): item=" << layout_item->get_name() << std::endl;
+     //std::cout << "debug: " << G_STRFUNC << ": item=" << layout_item->get_name() << std::endl;
 
      sharedptr<const Relationship> relationship = iter->second;
      const sharedptr<const Field> field_lookup = layout_item->get_full_field_details();
@@ -1627,12 +1547,7 @@ Gnome::Gda::Value Base_DB::get_lookup_value(const Glib::ustring& /* table_name *
     if(data_model && data_model->get_n_rows())
     {
       //There should be only 1 row. Well, there could be more but we will ignore them.
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
       result = data_model->get_value_at(0, 0);
-#else
-      std::auto_ptr<Glib::Error> error;
-      result = data_model->get_value_at(0, 0, error);
-#endif
     }
     else
     {
@@ -1661,7 +1576,7 @@ bool Base_DB::get_field_value_is_unique(const Glib::ustring& table_name, const s
   Glib::RefPtr<const Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(builder);
   if(data_model)
   {
-    //std::cout << "debug: Base_DB::get_field_value_is_unique(): table_name=" << table_name << ", field name=" << field->get_name() << ", value=" << value.to_string() << ", rows count=" << data_model->get_n_rows() << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": table_name=" << table_name << ", field name=" << field->get_name() << ", value=" << value.to_string() << ", rows count=" << data_model->get_n_rows() << std::endl;
     //The value is unique for this field, if the query returned no existing rows:
 
     result = (data_model->get_n_rows() == 0);
@@ -1687,7 +1602,7 @@ bool Base_DB::check_entered_value_for_uniqueness(const Glib::ustring& table_name
   {
     if(!get_field_value_is_unique(table_name, layout_field, field_value))
     {
-      //std::cout << "debug Base_DB::check_entered_value_for_uniqueness(): field=" << layout_field->get_name() << ", value is not unique: " << field_value.to_string() << std::endl;
+      //std::cout << "debug: " << G_STRFUNC << ": field=" << layout_field->get_name() << ", value is not unique: " << field_value.to_string() << std::endl;
 
       //Warn the user and revert the value:
       if(parent_window)
@@ -1841,7 +1756,7 @@ bool Base_DB::get_primary_key_is_in_foundset(const FoundSet& found_set, const Gn
   sharedptr<const Field> primary_key = get_field_primary_key_for_table(found_set.m_table_name);
   if(!primary_key)
   {
-    std::cerr << "Base_DB::get_primary_key_is_in_foundset(): No primary key found for table: " << found_set.m_table_name << std::endl;
+    std::cerr << G_STRFUNC << ": No primary key found for table: " << found_set.m_table_name << std::endl;
     return false;
   }
 
@@ -1890,7 +1805,7 @@ int Base_DB::count_rows_returned_by(const Glib::RefPtr<Gnome::Gda::SqlBuilder>&
 {
   if(!sql_query)
   {
-    std::cerr << "Base_DB::count_rows_returned_by(): sql_query was null." << std::endl;
+    std::cerr << G_STRFUNC << ": sql_query was null." << std::endl;
     return 0;
   }
 
@@ -1912,12 +1827,7 @@ int Base_DB::count_rows_returned_by(const Glib::RefPtr<Gnome::Gda::SqlBuilder>&
     Glib::RefPtr<Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(builder);
     if(datamodel && datamodel->get_n_rows() && datamodel->get_n_columns())
     {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
       Gnome::Gda::Value value = datamodel->get_value_at(0, 0);
-#else
-      std::auto_ptr<Glib::Error> value_error;
-      Gnome::Gda::Value value = datamodel->get_value_at(0, 0, value_error);
-#endif
       //This showed me that this contains a gint64: std::cerr << "DEBUG: value type=" << G_VALUE_TYPE_NAME(value.gobj()) << std::endl;
       //For sqlite, this is an integer
       if(value.get_value_type() == G_TYPE_INT64)
@@ -1926,7 +1836,7 @@ int Base_DB::count_rows_returned_by(const Glib::RefPtr<Gnome::Gda::SqlBuilder>&
         result = value.get_int();
     }
 
-  //std::cout << "DEBUG: count_rows_returned_by(): Returning " << result << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": Returning " << result << std::endl;
   return result;
 }
 
@@ -2001,7 +1911,7 @@ bool Base_DB::add_user(const Glib::ustring& user, const Glib::ustring& password,
   bool test = DbUtils::query_execute_string(strQuery);
   if(!test)
   {
-    std::cerr << "Base_DB::add_user(): CREATE USER failed." << std::endl;
+    std::cerr << G_STRFUNC << ": CREATE USER failed." << std::endl;
     return false;
   }
 
@@ -2010,7 +1920,7 @@ bool Base_DB::add_user(const Glib::ustring& user, const Glib::ustring& password,
   test = DbUtils::query_execute_string(strQuery);
   if(!test)
   {
-    std::cerr << "Base_DB::add_user(): ALTER GROUP failed." << std::endl;
+    std::cerr << G_STRFUNC << ": ALTER GROUP failed." << std::endl;
     return false;
   }
 
@@ -2026,7 +1936,7 @@ bool Base_DB::add_user(const Glib::ustring& user, const Glib::ustring& password,
     const Glib::ustring strQuery = "REVOKE ALL PRIVILEGES ON \"" + (*iter)->get_name() + "\" FROM \"" + user + "\"";
     const bool test = DbUtils::query_execute_string(strQuery);
     if(!test)
-      std::cerr << "Base_DB::add_user(): REVOKE failed." << std::endl;
+      std::cerr << G_STRFUNC << ": REVOKE failed." << std::endl;
   }
 
   return true;
@@ -2042,7 +1952,7 @@ bool Base_DB::remove_user(const Glib::ustring& user)
   const bool test = DbUtils::query_execute_string(strQuery);
   if(!test)
   {
-    std::cerr << "Base_DB::remove_user(): DROP USER failed" << std::endl;
+    std::cerr << G_STRFUNC << ": DROP USER failed" << std::endl;
     return false;
   }
 
@@ -2058,7 +1968,7 @@ bool Base_DB::remove_user_from_group(const Glib::ustring& user, const Glib::ustr
   const bool test = DbUtils::query_execute_string(strQuery);
   if(!test)
   {
-    std::cerr << "Base_DB::remove_user_from_group(): ALTER GROUP failed." << std::endl;
+    std::cerr << G_STRFUNC << ": ALTER GROUP failed." << std::endl;
     return false;
   }
 
@@ -2079,7 +1989,7 @@ bool Base_DB::set_database_owner_user(const Glib::ustring& user)
   const bool test = DbUtils::query_execute_string(strQuery);
   if(!test)
   {
-    std::cerr << "Base_DB::set_database_owner_user(): ALTER DATABASE failed." << std::endl;
+    std::cerr << G_STRFUNC << ": ALTER DATABASE failed." << std::endl;
     return false;
   }
 
@@ -2103,7 +2013,7 @@ bool Base_DB::disable_user(const Glib::ustring& user)
   const bool test = DbUtils::query_execute_string(strQuery);
   if(!test)
   {
-    std::cerr << "Base_DB::remove_user(): DROP USER failed" << std::endl;
+    std::cerr << G_STRFUNC << ": DROP USER failed" << std::endl;
     return false;
   }
 
