@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 //We use Python for calculated fields.
 //#include <Python.h> //Include it before anything else to avoid "_POSIX_C_SOURCE redefined".
@@ -51,7 +51,7 @@
 #include <glibmm/i18n.h>
 
 #ifdef GLOM_ENABLE_MAEMO
-#include <libossomm/init.h>
+#include <libosso.h>
 #include <hildonmm/init.h>
 #include <hildonmm/note.h>
 #include <hildonmm/program.h>
@@ -189,6 +189,7 @@ public:
   std::string m_arg_filename;
   bool m_arg_version;
   bool m_arg_restore;
+  bool m_arg_stop_auto_server_shutdown;
   bool m_arg_debug_sql;
   bool m_arg_debug_date_check;
 };
@@ -197,6 +198,7 @@ OptionGroup::OptionGroup()
 : Glib::OptionGroup("Glom", _("Glom options"), _("Command-line options for glom")),
   m_arg_version(false),
   m_arg_restore(false),
+  m_arg_stop_auto_server_shutdown(false),
   m_arg_debug_sql(false),
   m_arg_debug_date_check(false)
 {
@@ -217,6 +219,11 @@ OptionGroup::OptionGroup()
   entry_restore.set_description(_("Whether the filename is a .tar.gz backup to be restored."));
   add_entry(entry_restore, m_arg_restore);
 
+  Glib::OptionEntry entry_stop_auto_server_shutdown;
+  entry_stop_auto_server_shutdown.set_long_name("stop-auto-server-shutdown");
+  entry_stop_auto_server_shutdown.set_description(_("Do not automatically stop the database server if Glom quits. This is helpful for debugging with gdb."));
+  add_entry(entry_stop_auto_server_shutdown, m_arg_stop_auto_server_shutdown);
+
   Glib::OptionEntry entry_debug_sql;
   entry_debug_sql.set_long_name("debug_sql");
   entry_debug_sql.set_description(_("Show the generated SQL queries on stdout, for debugging."));
@@ -245,7 +252,7 @@ bool check_user_is_not_root_with_warning()
     message = ex.what();
   }
 #else
-  //std::cout << "ConnectionPool::check_user_is_not_root_with_warning(): geteuid()=" << geteuid() << ", getgid()=" << getgid() << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": geteuid()=" << geteuid() << ", getgid()=" << getgid() << std::endl;
 
   //This is very linux-specific. We should ifdef this out for other platforms.
   if(geteuid() == 0)
@@ -436,12 +443,22 @@ main(int argc, char* argv[])
   // We should not rely on the default locale of
   // any streams (we should always do an explicit imbue()),
   // but this is maybe a good default in case we forget.
-  std::locale::global(std::locale(""));
+  try
+  {
+    std::locale::global(std::locale(""));
+  }
+  catch(const std::runtime_error& ex)
+  {
+    //This has been known to throw an exception at least once:
+    //https://bugzilla.gnome.org/show_bug.cgi?id=619445
+    //This should tell us what the problem is:
+    std::cerr << G_STRFUNC << ": exception from std::locale::global(std::locale(\"\")): " << ex.what() << std::endl;
+  }
 
   Glom::libglom_init(); //Also initializes python.
 
 #ifdef GLOM_ENABLE_MAEMO
-  if(!(Osso::initialize("org.maemo.glom", PACKAGE_NAME)))
+  if(!(osso_initialize("org.maemo.glom", PACKAGE_NAME, FALSE /* obsolete */, 0)))
   {
     std::cerr << "Glom: Error while initializing libossomm" << std::endl;
     return 0;
@@ -458,61 +475,28 @@ main(int argc, char* argv[])
   PySys_SetArgv(argc, argv);
 
   std::auto_ptr<Gtk::Main> mainInstance;
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
-#endif
   {
     mainInstance = std::auto_ptr<Gtk::Main>( new Gtk::Main(argc, argv, context) );
   }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   catch(const Glib::Error& ex)
   {
     std::cerr << "Glom: Error while initializing gtkmm: " << ex.what() << std::endl;
     return 0;
   }
-#else
-  if (!mainInstance.get())
-  {
-    std::cerr << "Glom: Error while initializing gtkmm" << std::endl;
-    return 0;
-  }
-#endif
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
-#else
-  std::auto_ptr<Glib::Error> error;
-#endif // GLIBMM_EXCEPTIONS_ENABLED
   {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     context.parse(argc, argv);
-#else
-    context.parse(argc, argv, error);
-#endif // GLIBMM_EXCEPTIONS_ENABLED
   }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   catch(const Glib::OptionError& ex)
-#else
-  if(error.get())
-#endif
   {
-#ifndef GLIBMM_EXCEPTIONS_ENABLED
-    const Glib::OptionError* exptr = dynamic_cast<Glib::OptionError*>(error.get());
-    if(exptr)
-    {
-      const Glib::OptionError& ex = *exptr;
-#endif // !GLIBMM_EXCEPTIONS_ENABLED
       std::cout << _("Error while parsing command-line options: ") << std::endl << ex.what() << std::endl;
       std::cout << _("Use --help to see a list of available command-line options.") << std::endl;
       return 0;
-#ifndef GLIBMM_EXCEPTIONS_ENABLED
-    }
-    const Glib::Error& ex = *error.get();
-#else
   }
   catch(const Glib::Error& ex)
   {
-#endif
     std::cout << "Error: " << ex.what() << std::endl;
     return 0;
   }
@@ -524,9 +508,7 @@ main(int argc, char* argv[])
     return 0;
   }
 
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
-#endif
   {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
     gtksourceview::init();
@@ -636,6 +618,7 @@ main(int argc, char* argv[])
 
     pApplication->set_command_line_args(argc, argv);
     pApplication->set_show_sql_debug(group.m_arg_debug_sql);
+    pApplication->set_stop_auto_server_shutdown(group.m_arg_stop_auto_server_shutdown);
     Glom::ConnectionPool::get_instance()->set_show_debug_output(group.m_arg_debug_sql);
 
     const bool test = pApplication->init(input_uri, group.m_arg_restore); //Sets it up and shows it.
@@ -652,7 +635,6 @@ main(int argc, char* argv[])
     delete pApplication;
     pApplication = 0;
   }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   catch(const Glib::Exception& ex)
   {
     //If this happens then comment out the try/catch, and let the debugger show the call stack.
@@ -663,10 +645,12 @@ main(int argc, char* argv[])
     //If this happens then comment out the try/catch, and let the debugger show the call stack.
     std::cerr << "Glom: exception: \n  " << ex.what() << std::endl;
   }
-#endif // GLIBMM_EXCEPTIONS_ENABLED
 
   Glom::libglom_deinit();
 
+  //Tell libxml to clean things up to make valgrind more useful:
+  xmlCleanupParser();
+
   //These fail, probably because of previous things that are causing leaks:
   //cairo_debug_reset_static_data(); //This crashes with _cairo_hash_table_destroy: Assertion `hash_table->live_entries == 0' failed.
   //FcFini(); //This crashes with "FcCacheFini: Assertion `fcCacheChains[i] == ((void *)0)' failed."
