@@ -20,8 +20,9 @@
 
 #include "layoutwidgetfield.h"
 #include <glibmm/i18n.h>
-#include "../application.h"
+#include <glom/application.h>
 #include "../mode_data/flowtablewithfields.h"
+#include <iostream>
 
 namespace Glom
 {
@@ -82,7 +83,7 @@ void LayoutWidgetMenu::setup_menu()
     sigc::mem_fun(*this, &LayoutWidgetMenu::on_menupopup_activate_delete) );
 
   //TODO: This does not work until this widget is in a container in the window:s
-  App_Glom* pApp = get_application();
+  Application* pApp = get_application();
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
