@@ -23,7 +23,7 @@ void on_line_scanned(const std::vector<Glib::ustring>& row, guint /*line_number*
       iter != row.end();
       ++iter)
   {
-    //std::cout << "  debug: on_line_scanned(): item=" << *iter << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": item=" << *iter << std::endl;
 
     get_tokens_instance().push_back(*iter);
   }
@@ -46,7 +46,6 @@ bool check_tokens(const std::string& regex)
 {
   Glib::RefPtr<Glib::Regex> check;
 
-  #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     check = Glib::Regex::create(regex);
@@ -56,15 +55,6 @@ bool check_tokens(const std::string& regex)
     std::cerr << "Glib::Regex::create() failed: " << ex.what() << std::endl;
     return false;
   }
-  #else
-  std::auto_ptr<Glib::Error> ex;
-  check = Glib::Regex::create(regex, static_cast<Glib::RegexCompileFlags>(0), static_cast<Glib::RegexMatchFlags>(0), ex);
-  if(ex.get())
-  {
-    std::cerr << "Glib::Regex::create() failed: " << ex->what() << std::endl;
-    return false;
-  }
-  #endif
 
   if(!check && 0 == get_tokens_instance().size())
     return false;
@@ -97,6 +87,7 @@ int main(int argc, char* argv[])
   bool result = true;
   std::stringstream report;
 
+  // Test parsing of escaped quotes (double quotes in .csv mean a single quote in the actual field value):
   // test_dquoted_string
   {
     const char* raw = "\"a \"\"quoted\"\" token\",\"sans quotes\"\n";
@@ -110,64 +101,72 @@ int main(int argc, char* argv[])
       result = false;
   }
 
-  // Commented out, because why should we want to fail if there is no ending newline? murrayc.
-  /*
-  // test_skip_on_no_ending_newline
+  // Allow a line to have no newline at the end.
+  // test_allow_no_ending_newline
   {
     const char* raw = "\"token in first line\"\n\"2nd token\", \"but\", \"this\",\"line\",\"will\",\"be\",\"skipped\"";
     const bool finished_parsing = ImportTests::run_parser_from_buffer(&connect_signals, raw);
     const bool passed = (finished_parsing &&
                          check_tokens("token in first line") &&
-                         1 == get_tokens_instance().size());
+                         check_tokens("2nd token") &&
+                         8 == get_tokens_instance().size());
     get_tokens_instance().clear();
 
-    if(!ImportTests::check("test_skip_on_no_ending_newline", passed, report))
+    if(!ImportTests::check("test_allow_no_ending_newline", passed, report))
       result = false;
   }
-  */
 
-  // test_skip_on_no_quotes_around_token
+  //  Make sure that we do not demand quotes around items.
+  // test_allow_no_quotes
   {
-    const char* raw = "this,line,contains,only,empty,tokens\n";
+    const char* raw = "this,line,contains,some,tokens\n";
     const bool finished_parsing = ImportTests::run_parser_from_buffer(&connect_signals, raw);
 
     const bool passed = (finished_parsing &&
-                         check_tokens("^$") &&
-                         6 == get_tokens_instance().size());
+                         !check_tokens("^$") &&  //Check that there are no empty strings
+                         5 == get_tokens_instance().size());
     get_tokens_instance().clear();
 
-    if(!ImportTests::check("test_skip_on_no_quotes_around_token", passed, report))
+    if(!ImportTests::check("test_allow_no_quotes", passed, report))
       result = false;
   }
 
   // test_skip_spaces_around_separators
+  // TODO: This seems wise, but where is it specified? murrayc.
+  /*
   {
     const char* raw = "\"spaces\" , \"around\", \"separators\"\n";
     const bool finished_parsing = ImportTests::run_parser_from_buffer(&connect_signals, raw);
 
     const bool passed = (finished_parsing &&
-                         check_tokens("^(spaces|around|separators)$") &&
+                         check_tokens("^(spaces|around|separators)$") && //Matches these words with nothing else at the start or end.
                          3 == get_tokens_instance().size());
     get_tokens_instance().clear();
 
     if(!ImportTests::check("test_skip_spaces_around_separators", passed, report))
+    {
       result = false;
+    }
 
   }
+  */
 
   // test_fail_on_non_comma_separators
+  // TODO: Where is this behaviour (ignoring text between quoted text) specified? murray
+  /*
   {
     const char* raw = "\"cannot\"\t\"tokenize\"\t\"this\"\n";
     const bool finished_parsing = ImportTests::run_parser_from_buffer(&connect_signals, raw);
 
     const bool passed = (finished_parsing &&
-                         check_tokens("^cannottokenizethis$") &&
+                         check_tokens("^cannottokenizethis$") && //Matches this text with nothing else at the start or end.
                          1 == get_tokens_instance().size());
     get_tokens_instance().clear();
 
     if(!ImportTests::check("test_fail_on_non_comma_separators", passed, report))
       result = false;
   }
+  */
 
   // test_parse_newline_inside_quotes
   {
@@ -175,7 +174,7 @@ int main(int argc, char* argv[])
     const bool finished_parsing = ImportTests::run_parser_from_buffer(&connect_signals, raw);
 
     const bool passed = (finished_parsing &&
-                         check_tokens("^(cell with\nnewline|token on next line)$") &&
+                         check_tokens("^(cell with\nnewline|token on next line)$") && //Matches these texts with nothing else at the start or end.
                          2 == get_tokens_instance().size());
     get_tokens_instance().clear();
 
@@ -183,15 +182,17 @@ int main(int argc, char* argv[])
       result = false;
   }
 
-  /* TODO: Re-enable this (and fix the problem) when we can get the tests to run consistently, 
-   * without timing problems.
   // test_fail_on_non_matching_quotes
+  // Commented out because it's not clear what we want to do here.
+  // In this case, the ending newline would just appear as a quoted newline. murrayc.
+  /*
   {
     const char* raw = "\"token1\"\nthis quote has no partner\",\"token2\"\n";
     const bool finished_parsing = ImportTests::run_parser_from_buffer(&connect_signals, raw);
     const bool passed = (finished_parsing &&
                          check_tokens("token") &&
                          1 == get_tokens_instance().size());
+    print_tokens();
     get_tokens_instance().clear();
 
     if(!ImportTests::check("test_fail_on_non_matching_quotes", passed, report))
@@ -202,7 +203,9 @@ int main(int argc, char* argv[])
   // test_import_csv_file
   {
     // filename_to_uri expects absolute filenames
-    const std::string filename = Glib::build_filename(Glib::get_current_dir(), "tests/import/data/albums.csv");
+    const std::string filename =
+       Glib::build_filename(GLOM_TESTS_IMPORT_DATA_NOTINSTALLED,
+         "albums.csv");
     const bool finished_parsing = ImportTests::run_parser_on_file(&connect_signals, Glib::filename_to_uri(filename));
     const bool passed = (finished_parsing &&
                          8450 == get_tokens_instance().size());
@@ -218,4 +221,3 @@ int main(int argc, char* argv[])
 
   return result ? EXIT_SUCCESS : EXIT_FAILURE;
 }
-
